@@ -1,14 +1,12 @@
 from django.conf import settings as django_settings
 
-from attrdict import AttrDict
-
 from celery.beat import DEFAULT_MAX_INTERVAL
 
 
 DEFAULTS = {
     'CACHE_NAME': 'default',
     'UNIQUE_TASK_KEY_PREFIX': 'django-celery-extensions|unique',
-    'IGNORE_TASK_AFTER_SUCCESS_KEY_PREFIX': 'django-celery-extensions|ignore-after-success',
+    'IGNORE_TASK_KEY_PREFIX': 'django-celery-extensions|ignore',
     'BEATER_LOCK_KEY': 'django-celery-extensions|lock',
     'LOCK_TIMEOUT': DEFAULT_MAX_INTERVAL * 5,
     'LOCK_SLEEP':  DEFAULT_MAX_INTERVAL,
@@ -29,12 +27,7 @@ class Settings:
         if attr not in DEFAULTS:
             raise AttributeError('Invalid setting: "{}"'.format(attr))
 
-        value = getattr(django_settings, 'DJANGO_CELERY_EXTENSIONS_{}'.format(attr), DEFAULTS[attr])
-
-        if isinstance(value, dict):
-            value = AttrDict(value)
-
-        return value
+        return getattr(django_settings, 'DJANGO_CELERY_EXTENSIONS_{}'.format(attr), DEFAULTS[attr])
 
 
 settings = Settings()
